TextEdit

Struct TextEdit 

pub struct TextEdit { /* private fields */ }
Represents field where user can input their own text

let mut text_edit = TextEdit::new("First Name".to_owned());
let slot = SlotImpl::new();
text_edit.signal_text_changed().connect_slot(&slot);

// Whenewer TextEdit's text will be changed then `slot` will be triggered

Macros

[u_textedit!] simplifies TextEdit creation:

let slot = SlotImpl::new();

let text_edit = u_textedit!{
    placeholder: "First Name",
    signal_text_changed: slot,
};

Implementations

Source

impl TextEdit

pub fn new(placeholder: String) -> TextEdit

Creates new TextEdit with provided placeholder. You may be interested in [u_textedit!] to simplify TextEdit creation/setup.

let label = TextEdit::new("First Name".to_owned());
pub fn signal_text_changed(&mut self) -> &mut Signal<String>

The signal will trigger all connected slots whenever TextEdit’s text will be changed

let mut text_edit = u_textedit!{
    placeholder: "First Name".to_owned(),
};

let slot = SlotImpl::new();

// Or concider to use u_textedit!'s signal_text_changed parameter
text_edit.signal_text_changed().connect_slot(&slot);

// Whenever text will be changed, the `slot` will be triggered
pub fn slot_set_text(&mut self) -> &mut dyn Slot<String>

Slot to change TextEdit’s text

let text_edit = u_textedit!{
    placeholder: "First Name".to_owned(),
};

let mut signal = Signal::new();
signal.connect_slot(text_edit.slot_set_text());

// <...>

signal.emit("John".to_owned());
// text_edit's text will be set to "John"