Structs
- Property
- Property represents a storage which may receive new values via it’s slot and may notify about value change via it’s signal.
- Signal
- Signal can be used to inform others that new data is available.
- Slot
Impl - The main implementation for Slot trait. Allows to pull data from queue.
- Slot
Proxy - SlotProxy may be used as independed reference to the original Slot’s queue.
Traits
- Slot
- Slot represents a queue where data may be placed.